Attribute VB_Name = "TestCode"
' SpeedTest v0.01
' by Rick Murray  15th March 2007
' http://www.heyrick.co.uk/software/vbopti.html
'

Option Explicit

' A multimedia function to return the number of milliseconds since the last reset.
Declare Function timeGetTime Lib "WinMM" () As Long

' Variables. :-)
Public FP As Integer    ' File Pointer
Public LN As String     ' Logfile Name
Public TL As Long       ' Timing Loop value
Public TS As String     ' Temp String
Public ST As Long       ' Start Time
Public ET As Long       ' End Time
Public RT As Single     ' Resultant Time
Public BT As Long       ' Begin Time

Public Const LC As Long = 20000000 ' Loop Count

' Here be dragons...
Public Sub Main()
  Dim MyInt As Integer, MyLong As Long, MyVar As Variant, MyStr As String
  
  On Error Resume Next
  
  ' Confirm
  If (MsgBox("This test program will take a while (perhaps several minutes)." & vbCrLf & _
             "It is recommended that you close all other applications and let this " & _
             "program run" & vbCrLf & "without disturbances, and that you run it TWICE " & _
             "and take an average of the results." & vbCrLf & vbCrLf & _
             "Continue?", vbQuestion + vbYesNo + vbDefaultButton1) = vbNo) Then End

  ' Load and open the status window
  Load frmProgress
  frmProgress.Show
  DoEvents
  
  ' Screen hourglass
  Screen.MousePointer = vbHourglass

  ' The log file name is...
  LN = App.Path & "\VB speed log.txt"
  
  ' Open log file
  FP = FreeFile
  Open LN For Binary Access Write As FP

  ' Write a header
  TS = "VB timings log file - created " & Format(Now, "Short Date") & _
       " at " & Format(Now, "Short Time") & vbCrLf
  Put #FP, , TS
  TS = String$((Len(TS) - 2), "=") & vbCrLf & vbCrLf
  Put #FP, , TS
  TS = "Times are for repeating the process " & Format(LC, "##,###,###") & " times." & vbCrLf & vbCrLf
  Put #FP, , TS
  
  ' Record start time
  BT = timeGetTime
  
  
  ' ========
  ' PART ONE - variable timings
  ' ========
  ST = timeGetTime
  For TL = 1& To LC
    MyInt = 12345 ' <-- we assume this will assign 12345 as an Int, NOT via a Variant!
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Assigning to an Int from an Int      " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyLong = 12345
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Assigning to a Long from an Int      " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyLong = 12345&
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Assigning to a Long from a Long      " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyVar = 12345
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Assigning to a Variant from an Int   " & CStr(RT) & vbCrLf & vbCrLf
  Put #FP, , TS
  frmProgress.SetProgress 1, 7


  ' ========
  ' PART TWO - IF timings
  ' ========
  ST = timeGetTime
  For TL = 1& To LC
    If ((PA = 1) And (PB = 1)) Then
    End If
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "If loop with two functions together  " & CStr(RT) & vbCrLf
  Put #FP, , TS
  
  ST = timeGetTime
  For TL = 1& To LC
    If (PA = 1) Then
      If (PB = 1) Then
      End If
    End If
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "If loop with two functions separate  " & CStr(RT) & vbCrLf & vbCrLf
  Put #FP, , TS
  frmProgress.SetProgress 2, 7
  
  
  ' ==========
  ' PART THREE - Blank string timings
  ' ==========
  ST = timeGetTime
  For TL = 1& To LC
    MyStr$ = ""
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Blanking a string with " & Chr$(34) & Chr$(34) & "            " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyStr$ = vbNullString
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Blanking a string with vbNullString  " & CStr(RT) & vbCrLf & vbCrLf
  Put #FP, , TS
  frmProgress.SetProgress 3, 7


  ' =========
  ' PART FOUR - Testing is a string is blank timings
  ' =========
  MyStr$ = "heyrick"
  ST = timeGetTime
  For TL = 1& To LC
    If (MyStr$ = "") Then
    End If
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "String blank test with " & ChrW$(34) & ChrW$(34) & "            " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    If (MyStr$ = vbNullString) Then
    End If
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "String blank test with vbNullString  " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    If (Len(MyStr$) = 0) Then
    End If
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "String blank test with Len() = 0     " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    If (LenB(MyStr$) = 0) Then
    End If
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "String blank test with LenB() = 0    " & CStr(RT) & vbCrLf & vbCrLf
  Put #FP, , TS
  frmProgress.SetProgress 4, 7


  ' =========
  ' PART FIVE - To and from ASCII timings
  ' =========
  MyStr$ = "x"
  ST = timeGetTime
  For TL = 1& To LC
    MyInt = Asc(MyStr$)
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Converting string to int using Asc   " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyInt = AscW(MyStr$)
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Converting string to int using AscW  " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyStr$ = Chr(MyInt)
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Converting int to string using Chr   " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyStr$ = Chr$(MyInt)
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Converting int to string using Chr$  " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyStr$ = ChrW$(MyInt)
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Converting int to string using ChrW$ " & CStr(RT) & vbCrLf & vbCrLf
  Put #FP, , TS
  frmProgress.SetProgress 5, 7


  ' ========
  ' PART SIX - With and without $ timings
  ' ========
  ST = timeGetTime
  For TL = 1& To LC
    MyStr = LCase(Trim(" HeyRick "))
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "MyStr = LCase(Trim(" & ChrW$(34) & " HeyRick " & ChrW$(34) & ")      " & _
       CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyStr$ = LCase$(Trim$(" HeyRick "))
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "MyStr$ = LCase$(Trim$(" & ChrW$(34) & " HeyRick " & ChrW$(34) & ")   " & _
       CStr(RT) & vbCrLf & vbCrLf
  Put #FP, , TS
  frmProgress.SetProgress 6, 7


  ' ==========
  ' PART SEVEN - Number to string cast timings
  ' ==========
  ST = timeGetTime
  For TL = 1& To LC
    MyLong = Val("1234")
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Convert string num to long with Val  " & CStr(RT) & vbCrLf
  Put #FP, , TS

  ST = timeGetTime
  For TL = 1& To LC
    MyLong = CLng("1234")
  Next
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(ST)) / 1000#)
  TS = "Convert string num to long with CLng " & CStr(RT) & vbCrLf & vbCrLf
  Put #FP, , TS
  frmProgress.SetProgress 7, 7


  ' Done, close file and open it...
  ET = timeGetTime
  RT = ((CSng(ET) - CSng(BT)) / 1000#)
  TS = "Tests completed after " & CStr(RT) & " seconds." & vbCrLf
  Put #FP, , TS
  Close #FP
  Shell "Notepad " & ChrW$(34) & LN & ChrW$(34), vbNormalFocus
  
  ' Final tidyups
  Screen.MousePointer = vbDefault
  frmProgress.Hide
  Unload frmProgress
  End
End Sub

Private Function PA() As Integer
  PA = 0
End Function

Private Function PB() As Integer
  PB = 0
End Function

